@@ -6,7 +6,7 @@ http://sima-pc.com/nif.php
 http://en.wikipedia.org/wiki/Vat_number
 '''
 
-__version__ = '0.6'
+__version__ = '0.7'
 VIES_URL='http://ec.europa.eu/taxation_customs/vies/services/checkVatService.wsdl'
 
 def countries():
@@ -28,6 +28,16 @@ def mult_add(i, j):
         res += int(str(mult)[i])
     return res
 
+def mod1110(value):
+    '''
+    Compute ISO 7064, Mod 11,10
+    '''
+    t = 10
+    for i in value:
+        c = int(i)
+        t = (2 * ((t + c) % 10 or 10)) % 11
+    return (11 - t) % 10
+
 def check_vat_at(vat):
     '''
     Check Austria VAT number.
@@ -64,7 +74,7 @@ def check_vat_al(vat):
         int(vat[1:9])
     except ValueError:
         return False
-    if ord(vat[9]) < 65 and ord(vat[9]) > 90:
+    if ord(vat[9]) < 65 or ord(vat[9]) > 90:
         return False
     return True
 
@@ -118,26 +128,25 @@ def check_vat_cl(rut):
     Check Chile RUT number.
     '''
     try:
-        int(str(rut)[:len(str(rut))-1])
+        int(rut[:-1])
     except ValueError:
         return False
     sum = 0
-    RUTLen = len(str(rut))
-    for i in range (RUTLen - 2, -1, -1):
-        sum += int(str(rut)[i]) * (((RUTLen - 2 - i) % 6) + 2)
+    for i in range(len(rut) - 2, -1, -1):
+        sum += int(rut[i]) * (((len(rut) - 2 - i) % 6) + 2)
     check = 11 - (sum % 11)
     if check == 11:
-        return str(rut)[len(str(rut)) -1] == '0'
+        return rut[-1] == '0'
     elif check == 10:
-        return str(rut)[len(str(rut)) -1].upper() == 'K'
+        return rut[-1].upper() == 'K'
     else:
-        return str(check) == str(rut)[len(str(rut)) -1]
+        return check == int(rut[-1])
 
 def check_vat_co(rut):
     '''
     Check Colombian RUT number.
     '''
-    if len(str(rut)) != 10:
+    if len(rut) != 10:
         return False
     try:
         int(rut)
@@ -145,13 +154,12 @@ def check_vat_co(rut):
         return False
     nums = [3, 7, 13, 17, 19, 23, 29, 37, 41, 43, 47, 53, 59, 67, 71]
     sum = 0
-    RUTLen = len(str(rut))
-    for i in range (RUTLen - 2, -1, -1):
-        sum += int(str(rut)[i]) * nums [RUTLen - 2 - i]
+    for i in range (len(rut) - 2, -1, -1):
+        sum += int(rut[i]) * nums[len(rut) - 2 - i]
     if sum % 11 > 1:
-         return str(rut)[RUTLen - 1] == str(11 - (sum % 11))
+         return int(rut[-1]) == 11 - (sum % 11)
     else:
-         return str(rut)[RUTLen - 1] == str(sum % 11)
+         return int(rut[-1]) == sum % 11
 
 def check_vat_cy(vat):
     '''
@@ -288,9 +296,8 @@ def check_vat_cz(vat):
             if int(vat[4:6]) > 31:
                 return False
         if (int(vat[0:2]) + int(vat[2:4]) + int(vat[4:6]) + int(vat[6:8]) +
-                int(vat[8:10])) % 11 != 0:
-            return False
-        if int(vat[0:10]) % 11 != 0:
+                int(vat[8:10])) % 11 != 0 \
+                or int(vat[0:10]) % 11 != 0:
             return False
     return True
 
@@ -632,6 +639,21 @@ def check_vat_el(vat):
     '''
     return check_vat_gr(vat)
 
+def check_vat_hr(vat):
+    '''
+    Check Croatia VAT number.
+    '''
+    if len(vat) != 11:
+        return False
+    try:
+        int(vat)
+    except ValueError:
+        return False
+    check = mod1110(vat[:-1])
+    if check != int(vat[10]):
+        return False
+    return True
+
 def check_vat_hu(vat):
     '''
     Check Hungary VAT number.
@@ -1039,7 +1061,7 @@ def check_vat_sk(vat):
     if len(vat) not in(9, 10):
         return False
 
-    if int(vat[0:2]) == 0 and len(vat) == 10:
+    if int(vat[0:2]) in (0, 10, 20) and len(vat) == 10:
         return True
 
     if len(vat) == 10:
